@@ -102,7 +102,7 @@ sub catalyst_files {
     my @path = split '-', $self->name;
     for my $orig (@files) {
         my $path = File::Spec->catdir( 'blib', 'lib', @path, $orig );
-        rcopy( $orig, $path );
+        File::Copy::Recursive::rcopy( $orig, $path );
     }
 }
 
